# -*- coding: utf-8 -*-

import pytest


@pytest.hookspec(firstresult=True)
def pytest_emoji_passed(config):
    """Called to get a representation for a passed test item.

    Requires a tuple of (<shortletter>, <verbose-word>)
    pytest defaults to ('.', 'PASSED')
    """


@pytest.hookspec(firstresult=True)
def pytest_emoji_failed(config):
    """Called to get a representation for a failed test item.

    Requires a tuple of (<shortletter>, <verbose-word>)
    pytest defaults to ('F', 'FAILED')
    """


@pytest.hookspec(firstresult=True)
def pytest_emoji_skipped(config):
    """Called to get a representation for a skipped test item.

    Requires a tuple of (<shortletter>, <verbose-word>)
    pytest default to ('s', 'SKIPPED')
    """


@pytest.hookspec(firstresult=True)
def pytest_emoji_error(config):
    """Called to get a representation for a error test item.

    Requires a tuple of (<shortletter>, <verbose-word>)
    pytest defaults to ('E', 'ERROR')
    """


@pytest.hookspec(firstresult=True)
def pytest_emoji_xfailed(config):
    """Called to get a representation for a xfailed test item.

    Requires a tuple of (<shortletter>, <verbose-word>)
    pytest defaults to ('x', 'xfail')
    """


@pytest.hookspec(firstresult=True)
def pytest_emoji_xpassed(config):
    """Called to get a representation for a xpassed test item.

    Requires a tuple of (<shortletter>, <verbose-word>)
    pytest defaults to ('X', 'XPASS')
    """



# -*- coding: utf-8 -*-

import textwrap

import pytest


@pytest.fixture
def emoji_tests():
    return textwrap.dedent("""
        # -*- coding: utf-8 -*-

        import pytest

        def test_passed():
            assert True

        def test_failed():
            assert False

        @pytest.mark.xfail
        def test_xfailed():
            assert False

        @pytest.mark.xfail
        def test_xpassed():
            assert True

        def test_new_pytest_is_awesome():
            assert True

        @pytest.mark.skipif(True, reason='nope')
        def test_skipped():
            assert True

        @pytest.fixture
        def lol():
            raise RuntimeError

        @pytest.mark.raph
        def test_error(lol):
            assert True

        """)


@pytest.fixture
def custom_emojis():
    return textwrap.dedent("""
        def pytest_emoji_passed(config):
            return u'🍪 ', u'PASSED 🍪 '


        def pytest_emoji_failed(config):
            return u'😿 ', u'FAILED 😿 '


        def pytest_emoji_skipped(config):
            return u'🙈 ', u'SKIPPED 🙈 '


        def pytest_emoji_error(config):
            return u'💩 ', u'ERROR 💩 '


        def pytest_emoji_xfailed(config):
            return u'🤓 ', u'xfail 🤓 '


        def pytest_emoji_xpassed(config):
            return u'😜 ', u'XPASS 😜 '

        """)


def test_emoji_disabled_by_default_verbose(testdir, emoji_tests):
    # create a temporary pytest test module
    testdir.makepyfile(emoji_tests)

    # run pytest with the following cmd args
    result = testdir.runpytest(
        '-v',
    )

    # fnmatch_lines does an assertion internally
    result.stdout.fnmatch_lines([
        '*::test_passed PASSED',
        '*::test_failed FAILED',
        '*::test_xfailed xfail',
        '*::test_xpassed XPASS',
        '*::test_new_pytest_is_awesome PASSED',
        '*::test_skipped SKIPPED',
        '*::test_error ERROR',
    ])

    # make sure that that we get a '1' exit code
    # as we have at least one failure
    assert result.ret == 1


def test_emoji_enabled_verbose(testdir, emoji_tests):
    # create a temporary pytest test module
    testdir.makepyfile(emoji_tests)

    # run pytest with the following cmd args
    result = testdir.runpytest(
        '-v',
        '--emoji',
    )

    # fnmatch_lines does an assertion internally
    result.stdout.fnmatch_lines([
        '*::test_passed PASSED 😃 ',
        '*::test_failed FAILED 😰 ',
        '*::test_xfailed xfail 😞 ',
        '*::test_xpassed XPASS 😲 ',
        '*::test_new_pytest_is_awesome PASSED 😃 ',
        '*::test_skipped SKIPPED 🙄 ',
        '*::test_error ERROR 😡 ',
    ])

    # make sure that that we get a '1' exit code
    # as we have at least one failure
    assert result.ret == 1


def test_emoji_enabled_custom_verbose(testdir, emoji_tests, custom_emojis):
    testdir.makeconftest(custom_emojis)

    # create a temporary pytest test module
    testdir.makepyfile(emoji_tests)

    # run pytest with the following cmd args
    result = testdir.runpytest(
        '-v',
        '--emoji',
    )

    # fnmatch_lines does an assertion internally
    result.stdout.fnmatch_lines([
        '*::test_passed PASSED 🍪 ',
        '*::test_failed FAILED 😿 ',
        '*::test_xfailed xfail 🤓 ',
        '*::test_xpassed XPASS 😜 ',
        '*::test_new_pytest_is_awesome PASSED 🍪 ',
        '*::test_skipped SKIPPED 🙈 ',
        '*::test_error ERROR 💩 ',
    ])

    # make sure that that we get a '1' exit code
    # as we have at least one failure
    assert result.ret == 1


def test_emoji_disabled_by_default_non_verbose(testdir, emoji_tests):
    # create a temporary pytest test module
    testdir.makepyfile(emoji_tests)

    # run pytest with the following cmd args
    result = testdir.runpytest()

    # fnmatch_lines does an assertion internally
    result.stdout.fnmatch_lines([
        '* .FxX.sE',
    ])

    # make sure that that we get a '1' exit code
    # as we have at least one failure
    assert result.ret == 1


def test_emoji_enabled_non_verbose(testdir, emoji_tests):
    # create a temporary pytest test module
    testdir.makepyfile(emoji_tests)

    # run pytest with the following cmd args
    result = testdir.runpytest(
        '--emoji',
    )

    # fnmatch_lines does an assertion internally
    result.stdout.fnmatch_lines([
        '* 😃 😰 😞 😲 😃 🙄 😡 ',
    ])

    # make sure that that we get a '1' exit code
    # as we have at least one failure
    assert result.ret == 1


def test_emoji_enabled_custom_non_verbose(testdir, emoji_tests, custom_emojis):
    testdir.makeconftest(custom_emojis)

    # create a temporary pytest test module
    testdir.makepyfile(emoji_tests)

    # run pytest with the following cmd args
    result = testdir.runpytest(
        '--emoji',
    )

    # fnmatch_lines does an assertion internally
    result.stdout.fnmatch_lines([
        '* 🍪 😿 🤓 😜 🍪 🙈 💩 ',
    ])

    # make sure that that we get a '1' exit code
    # as we have at least one failure
    assert result.ret == 1



# -*- coding: utf-8 -*-

import pytest

from pytest_emoji import hooks


def pytest_addhooks(pluginmanager):
    # Register new hooks from pytest_emoji.hooks
    pluginmanager.add_hookspecs(hooks)


def pytest_emoji_passed(config):
    # SMILING FACE WITH OPEN MOUTH
    return u'😃 ', u'PASSED 😃 '


def pytest_emoji_failed(config):
    # FACE WITH OPEN MOUTH AND COLD SWEAT
    return u'😰 ', u'FAILED 😰 '


def pytest_emoji_skipped(config):
    # FACE WITH ROLLING EYES
    return u'🙄 ', u'SKIPPED 🙄 '


def pytest_emoji_error(config):
    # POUTING FACE
    return u'😡 ', u'ERROR 😡 '


def pytest_emoji_xfailed(config):
    # DISAPPOINTED FACE
    return u'😞 ', u'xfail 😞 '


def pytest_emoji_xpassed(config):
    # DIZZY FACE
    return u'😲 ', u'XPASS 😲 '


def pytest_report_teststatus(report):
    if pytest.config.option.emoji is False:
        # Do not modify reporting unless pytest
        # is called with --emoji
        return

    error_hook = pytest.config.hook.pytest_emoji_error
    failed_hook = pytest.config.hook.pytest_emoji_failed
    passed_hook = pytest.config.hook.pytest_emoji_passed
    skipped_hook = pytest.config.hook.pytest_emoji_skipped
    xfailed_hook = pytest.config.hook.pytest_emoji_xfailed
    xpassed_hook = pytest.config.hook.pytest_emoji_xpassed

    # Handle error and skipped in setup and teardown phase
    if report.when in ('setup', 'teardown'):
        if report.failed:
            short, verbose = error_hook(config=pytest.config)
            return 'error', short, verbose
        elif report.skipped:
            short, verbose = skipped_hook(config=pytest.config)
            return 'skipped', short, verbose

    # Handle xfailed and xpassed
    if hasattr(report, 'wasxfail'):
        if report.skipped:
            short, verbose = xfailed_hook(config=pytest.config)
            return 'xfailed', short, verbose
        elif report.passed:
            short, verbose = xpassed_hook(config=pytest.config)
            return 'xpassed', short, verbose
        else:
            return '', '', ''

    # Handle passed, skipped and failed in call phase
    if report.when == 'call':
        if report.passed:
            short, verbose = passed_hook(config=pytest.config)
        elif report.skipped:
            short, verbose = skipped_hook(config=pytest.config)
        elif report.failed:
            short, verbose = failed_hook(config=pytest.config)
        return report.outcome, short, verbose


def pytest_addoption(parser):
    group = parser.getgroup('emoji')
    group.addoption(
        '--emoji',
        action='store_true',
        default=False,
        help='Add emojis to the test result log.'
    )



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os

from setuptools import setup


def read(fname):
    file_path = os.path.join(os.path.dirname(__file__), fname)

    with open(file_path, encoding='utf-8') as f:
        contents = f.read()

    return contents


setup(
    name='pytest-emoji',
    version='0.1.0',
    author='Raphael Pierzina',
    author_email='raphael@hackebrot.de',
    maintainer='Raphael Pierzina',
    maintainer_email='raphael@hackebrot.de',
    license='MIT',
    url='https://github.com/hackebrot/pytest-emoji',
    description='pytest + emoji',
    long_description=read('README.rst'),
    packages=[
        'pytest_emoji',
    ],
    package_dir={'pytest_emoji': 'pytest_emoji'},
    include_package_data=True,
    install_requires=['pytest>=3.0.1'],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Framework :: Pytest',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Testing',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: Implementation :: CPython',
        'Operating System :: OS Independent',
        'License :: OSI Approved :: MIT License',
    ],
    entry_points={
        'pytest11': [
            'emoji = pytest_emoji.plugin',
        ],
    },
    keywords=['pytest', 'emoji'],
)
